@@ -3,20 +3,20 @@
 #' @export
 #'
 #' @param key Occurrence key
-#' @param return One of data, hier, meta, or all. If 'data', a data.frame with the
-#'    data. 'hier' returns the classifications in a list for each record. meta
-#'    returns the metadata for the entire call. 'all' gives all data back in a list.
-#'    Ignored if \code{verbatim=TRUE}.
-#' @param verbatim Return verbatim object (TRUE) or cleaned up object (FALSE, default).
-#' @param fields (character) Default ('minimal') will return just taxon name, key, latitude, and
-#'    longitute. 'all' returns all fields. Or specify each field you want returned by name, e.g.
-#'    fields = c('name','decimalLatitude','altitude').
-#' @param ... Further named parameters, such as \code{query}, \code{path}, etc, passed on to
-#' \code{\link[httr]{modify_url}} within \code{\link[httr]{GET}} call. Unnamed parameters will be
-#' combined with \code{\link[httr]{config}}.
+#' @param return One of data, hier, meta, or all. If 'data', a data.frame
+#' with the data. 'hier' returns the classifications in a list for each record.
+#' meta returns the metadata for the entire call. 'all' gives all data back
+#' in a list. Ignored if `verbatim=TRUE`.
+#' @param verbatim Return verbatim object (TRUE) or cleaned up object (FALSE,
+#' default).
+#' @param fields (character) Default ('minimal') will return just taxon name,
+#' key, latitude, and longitute. 'all' returns all fields. Or specify each
+#' field you want returned by name, e.g. fields = c('name',
+#' 'decimalLatitude','altitude').
+#' @template occ
 #'
 #' @return A data.frame or list of data.frame's.
-#' @references \url{http://www.gbif.org/developer/occurrence#occurrence}
+#' @references <http://www.gbif.org/developer/occurrence#occurrence>
 #'
 #' @examples \dontrun{
 #' occ_get(key=766766824, return='data')
@@ -29,19 +29,20 @@
 #' # Verbatim data
 #' occ_get(key=766766824, verbatim=TRUE)
 #' occ_get(key=766766824, fields='all', verbatim=TRUE)
-#' occ_get(key=766766824, fields=c('scientificName', 'lastCrawled', 'county'), verbatim=TRUE)
+#' occ_get(key=766766824, fields=c('scientificName', 'lastCrawled', 'county'),
+#'   verbatim=TRUE)
 #' occ_get(key=c(766766824, 620594291, 766420684), verbatim=TRUE)
 #' occ_get(key=c(766766824, 620594291, 766420684), fields='all', verbatim=TRUE)
 #' occ_get(key=c(766766824, 620594291, 766420684),
-#'    fields=c('scientificName', 'decimalLatitude', 'basisOfRecord'), verbatim=TRUE)
+#'    fields=c('scientificName', 'decimalLatitude', 'basisOfRecord'),
+#'    verbatim=TRUE)
 #'
 #' # Pass in curl options
-#' library("httr")
-#' occ_get(key=766766824, config=verbose())
-#' # occ_get(key=766766824, config=progress())
+#' occ_get(key=766766824, curlopts = list(verbose=TRUE))
 #' }
 
-occ_get <- function(key=NULL, return='all', verbatim=FALSE, fields='minimal', ...) {
+occ_get <- function(key=NULL, return='all', verbatim=FALSE, fields='minimal',
+                    curlopts = list()) {
 
   stopifnot(is.numeric(key))
   return <- match.arg(return, c("meta", "data", "hier", "all"))
@@ -53,7 +54,7 @@ occ_get <- function(key=NULL, return='all', verbatim=FALSE, fields='minimal', ..
     } else {
       url <- sprintf('%s/occurrence/%s', gbif_base(), x)
     }
-    gbif_GET(url, NULL, FALSE, ...)
+    gbif_GET(url, NULL, FALSE, curlopts)
   }
 
   # Get data
